Learn R Programming

oppar (version 1.0.0)

maupin: Maupin's TGFb data and a TGFb gene signature

Description

A list consisting of two components: data: A matrix consisting of gene expression values on 3 control and 3 TGFb treated samples. sig: A TGFb gene signature. A dataframe containing a gene signature and information on whether genes in the signature are up or dow regulated.

Usage

data(Maupin)

Arguments

Value

A list of 2

Format

A list of two components:
M_Ctrl_R1
In data; Control Sample - Replicate 1
M_Ctrl_R2
In data; Control Sample - Replicate 2
M_Ctrl_R3
In data; Control Sample - Replicate 3
M_TGFb_R1
In data; Control Sample - Replicate 1
M_TGFb_R2
In data; Control Sample - Replicate 2
M_TGFb_R3
In data; Control Sample - Replicate 3
EntrezID
In sig; The Entrez IDs
Symbol
In sig; Gene symbols
upDown
In sig; Direction of regulation e.g. up, down